@@ -1,6 +1,6 @@
 #!/bin/sh
 
-#Copyright (C) 2006 NTT DATA Corporation
+#Copyright (C) 2006, 2007 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -16,10 +16,10 @@ EXEC_PATH=${0%/*}
 echo "###################################################################"
 echo "###                                                             ###"
 echo "### 運用管理ソフトウェア Hinemos  クライアント                  ###"
-echo "###                                   インストーラ   Ver 2.1    ###"
+echo "###                                   インストーラ   Ver 2.2.0  ###"
 echo "###                                                             ###"
-echo "###  2006/9/29                                                  ###"
-echo "###  Copyright (C) 2006 NTT DATA Corporation.                   ###"
+echo "###  2006/03/28                                                 ###"
+echo "###  Copyright (C) 2006, 2007 NTT DATA Corporation.             ###"
 echo "###################################################################"
 
 
